@@ -12,6 +12,8 @@ from pygitscrum.git_daily import git_daily
 from pygitscrum.git_track import git_track
 from pygitscrum.git_wip import git_wip
 from pygitscrum.git_prune import git_prune
+from pygitscrum.git_fetch import git_fetch
+from pygitscrum.git_show import git_show
 
 
 def pygitscrum():
@@ -20,21 +22,23 @@ def pygitscrum():
     """
     args = compute_args()
 
-    files = scan_directories()
-
     if args.version:
         version_pygitscrum()
     elif args.update:
         update_pygitscrum()
     elif args.track:
-        git_track(files)
+        git_track(scan_directories())
+    elif args.fetch:
+        git_fetch(scan_directories())
     elif args.check:
-        git_check(files)
+        git_check(scan_directories())
     elif args.daily:
-        git_daily(files)
+        git_daily(scan_directories())
     elif args.search:
-        git_search(files)
+        git_search(scan_directories())
+    elif args.show:
+        git_show(scan_directories())
     elif args.wip:
-        git_wip(files)
+        git_wip(scan_directories())
     elif args.prune:
-        git_prune(files)
+        git_prune(scan_directories())
